@@ -62,11 +62,13 @@ class RelationalAnnotation(Annotation):
 
     @abstractmethod
     def check(self, observed_values: List[Tuple[Any, int]]) -> "AnnotationResult":
-        ...
+        ... # pragma: no cover
 
 
 class BeforeAnnotation(RelationalAnnotation):
     """
+    pybryt.BeforeAnnotation()
+
     Annotation for asserting that one annotation occurs before another.
 
     When being :py:meth:`check<pybryt.BeforeAnnotation.check>` is called, ensures that all child 
